/*  QWKPkt.Rexx 1.1
    Convert QWK message files to a FTS-1 compatible *.PKT file
    Rick Eyre 2 November 1993
    CONTROL.DAT and MESSAGE.DAT files must be present in current directory

    syntax:  rx qwkpkt [node from, in 4D format] [your node, 4D format]
*/

parse arg fromnode tonode

parse var fromnode fzone ':' fnet '/' fnode '.' fmpt
parse var tonode tzone ':' tnet '/' tnode '.' topt

if (fmpt<1) then fmpt=0
if (topt<1) then topt=0

say fmpt||'  '||topt

passwd=copies('0'x,8)

fnodewrd=makeword(fnode)
tnodewrd=makeword(tnode)
fnetwrd=makeword(fnet)
tnetwrd=makeword(tnet)
fzonewrd=makeword(fzone)
tzonewrd=makeword(tzone)
fpntwrd=makeword(fmpt)
tpntwrd=makeword(topt)

tday=date()||"  "time()
tday=delstr(tday,8,2)
tyr=word(tday,3)
yearwrd=makeword(tyr)
mnth=left(date("U"),2)-1
mnthwrd=makeword(mnth)
dye=left(tday,2)
daywrd=makeword(dye)
hour=substr(tday,12,2)
hrwrd=makeword(hour)
minute=substr(tday,15,2)
minwrd=makeword(minute)
second=right(tday,2)
secwrd=makeword(second)

mnthstr="JanFebMarAprMayJunJulAugSepOctNovDec"

  Days=Date("I")                /* Find number of days since 1/1/78        */
  Secs=Time("S")                /* Find number of secs since midnight      */
  ID=(Days*86400)+Secs          /* Add up all the seconds for the MsgID    */
  MID=D2X(ID)                   /* Convert to Hex */
  fname=MID'.PKT'

/*  write PKT header  FSC-0039 format  */

call open('pktfile',fname,'w')
writech('pktfile',fnodewrd||tnodewrd||yearwrd||mnthwrd||daywrd||hrwrd)
writech('pktfile',minwrd||secwrd||'00000200'x||fnetwrd||tnetwrd||'0100'x)
writech('pktfile',passwd||fzonewrd||tzonewrd||'0000000100000100'x)
writech('pktfile',fzonewrd||tzonewrd||fpntwrd||tpntwrd||copies('0'x,4))

/*  create arealist from CONTROL.DAT  */

call open(control,"CONTROL.DAT",r)
do i=1 to 10
    dumline=readln(control)
    end i
j=readln(control)
i=compress(j,'0d'x)+1

do for i
    k=readln(control)
    l=compress(k,'0d'x)
    area.l=upper(readln(control))
    end

call close(control)

/*  start reading messages.dat, then skip packet header  */

call open(message,"MESSAGES.DAT",r)
readch(message,128)

do until eof(message)=1
    call qwktopkt
end

writech('pktfile','0000'x)
call close('pktfile')
exit 0

/*  read message header  */
qwktopkt:

dumline=readch(message,8)
if eof(message) then return
mon=readch(message,2)
readch(message)
don=readch(message,2)
dumline=readch(message)
yon=readch(message,2)
hon=readch(message,2)
dumline=readch(message)
mion=readch(message,2)
son=0
tdate=don||' '||substr(mnthstr,mon*3-2,3)||' '||yon||'  '||hon||':'||mion||':00'

whoto=strip(readch(message,25),'T')
whofrom=strip(readch(message,25),'T')
about=strip(readch(message,25),'T')
readch(message,20)
blox=strip(readch(message,6),'T')
bloka=(blox-1)*128
dumline=readch(message)
conflo=readch(message)
confhi=readch(message)
conf=c2d(confhi||conflo)
thisconf=area.conf
dumline=readch(message,3)

say whofrom||' '||whoto||' '||about||' '||thisconf

writech('pktfile','0200'x||fnodewrd||tnodewrd||fnetwrd||tnetwrd)
writech('pktfile','00000000'x||tdate||'00'x||whoto||'00'x)
writech('pktfile',whofrom||'00'x||about||'00'x)
writeln('pktfile','AREA:'||thisconf)

  txt=readch(message,bloka)
  ttx=translate(txt,'0d'x,'e3'x)
  txt=strip(ttx,'T')
  writech('pktfile',txt)

writech('pktfile','00'x)
return

/* Functions */

makeword:
numero=arg(1)
numerwrd=d2c(numero//256)||d2c(numero%256)
return numerwrd